package jdk.internal.jshell.tool.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "21.0.1+12-LTS" },
            { "jdk", "21.0.1" },
            { "release", "21.0.1" },
        };
    }
}
